/*
    Up to this point we've looked at some of the basics of console output with 
    C/C++ and some of the basics of functions and passing pointer and reference 
    parameters.  We've also discussed character strings and arrays some.  You
    might be thinking that in some ways its not too different than BASIC.  Well,
    it actually is quite different from basic and we'll now start discussing 
    some of the really painful differences that are going to give BASIC
    programmers the most difficulty.  And, if you havn't guessed already, the
    really painful differences concern strings.
    
    The way I presented all the programs up to this point really masked the 
    problems and I did that intentionally.  For example, if I wanted to show
    how to output a character string consisting of my name I set up the program 
    like so...
    
    char szBuffer[] = "Frederick J. Harris"
    
    printf("My Name Is %s\n", szBuffer); 
    
    ...and the output would be...
    
    My Name Is Frederick J. Harris
    Press Any Key To Continue....
    
    In the top line above we really have an array variable declaration combined
    with its initialization.  szBuffer without the square brackets is a pointer
    to the first byte of storage where the 'F' is stored; szBuffer[1] would be
    'r'; szbuffer[2] would be 'e', etc.  So what really happens when the C
    compiler compiles a line such as...
    
    char szBuffer[] = "Frederick J. Harris"
    
    ...is it allocates at least 20 bytes to hold the string and a null 
    terminator, and four bytes for the pointer variable szBuffer itself.  
    However, what you can't do is the following...
    
    char szBuffer[20];
    szBuffer = "Frederick J. Harris";
    
    If you try to compile something like the above, the GNU compilers will give
    an error message something like this...
    
    "ISO C++ forbids assignment of arrays"
    
    There is a way to do it however; you need to use the string primitives in
    string.h.  The char array declaration...
    
    char szBuffer[20];
    
    will indeed allocate storage for a string of 19 characters plus a null
    terminator; but it won't put the string there.  You have to do it yourself
    with the strcpy()) function.  This function takes two pointer parameters; 
    the first parameter is a pointer to the destination of where a null 
    terminated string is to be copied; and the second parameter is a pointer to 
    the source string to be copied.  So the complete code segment would look 
    like this...
    
    char szBuffer[20];
    strcpy(szBuffer, "Frederick J. Harris");
    printf("szBuffer = %s\n", szBuffer);

    Below is a complete little program showing the necessary includes and steps: 
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

int main()
{
 char szBuffer[20];
 
 strcpy(szBuffer, "Frederick J. Harris");
 printf("szBuffer = %s\n",szBuffer);   
 getchar();
 
 return EXIT_SUCCESS;
}

/*
Output:
szBuffer = Frederick J. Harris
*/


